"""
File: constants
Author: Om Prakash <omprakash@gofynd.com>
Date: 16/03/2017

It contains constant values for bluedart.
"""

BLUEDART_DEBUG_BASE_URL = 'http://netconnect.bluedart.com/Demo/ShippingAPI/'
BLUEDART_BASE_URL = 'https://netconnect.bluedart.com/Ver1.7/ShippingAPI/'
TEST_CREDS = {
    "api_type": "S",
    "licence_key": "ieuiowueeriooprijnxcvoiewponcx",
    "tracking_license_key": "uyq9827iojncxlkjweu32298msdhoewo",
    "login_id": "BOM06144",
    "version": "1.7",
    "customer_code": "099960",
    "debug": True
}
